@@ -110,8 +110,7 @@ numbervars(Term, From, Next) :-
 %
 %  the setup_call_cleanup/3 meta-predicate is only strictly required if
 %  the backend Prolog compiler supports a compatible multi-threading
-%  implementation but the unit test framework and the port profiler tool
-%  can also take advantage of it
+%  implementation but the developer tools can also take advantage of it
 %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
@@ -198,7 +197,7 @@ numbervars(Term, From, Next) :-
 '$lgt_prolog_feature'(prolog_version, (Major, Minor, Path)) :-
 	?????
 '$lgt_prolog_feature'(prolog_compatible_version, '@>='((Major, Minor, Path))).
-'$lgt_prolog_feature'(prolog_conformance, ?????).	% either iso_lax or iso_strict
+'$lgt_prolog_feature'(prolog_conformance, ?????).	% either lax or strict
 
 '$lgt_prolog_feature'(encoding_directive, ?????).
 '$lgt_prolog_feature'(tabling, ?????).
